==> jdvue-0.1.3.tgz: package/src/components/index.js <==
import '../assets/common.less'

import Actionsheet from './actionsheet/index.vue'; // 已经完成
import Button from './button/index.vue';
import ButtonGroup from './button-group/index.vue';
import Cell from './cell/index.vue';
import CellItem from './cell-item/index.vue';
import Checkbox from './checkbox/index.vue';
import CheckboxGroup from './checkbox-group/index.vue';
import Col from './col/index.vue';
import Collapse from './collapse/index.vue';
import CollapseItem from './collapse-item/index.vue';
import Confirm from './confirm/index.vue';
import CountUp from './count-up/index.vue';
import Dialog from './dialog/index.vue';
import FullLoad from './full-load/index.vue'; // 已经完成
import Icon from './icon/index.vue';
import Input from './input/index.vue';
import KeyInput from './key-input/index.vue';
import Loading from './loading/index.vue'; // 已经完成
import Marquee from './marquee/index.vue'; // 已经完成
import Notice from './notice/index.vue';
import Number from './number/index.vue';
import Popup from './popup/index.vue';
import Radio from './radio/index.vue';
import RadioGroup from './radio-group/index.vue';
import Row from './row/index.vue';
import Scroll from './scroll/index.vue';
import Share from './share/index.vue'; // 已经完成
import Slide from './slide/index.vue';
import SlideItem from './slide-item/index.vue';
import Step from './step/index.vue';
import StepItem from './step-item/index.vue';
import Tabs from './tabs/index.vue';
import TabsItem from './tabs-item/index.vue';
import Toast from './toast/index.vue'; // 已经完成
import Vlink from './vlink/index.vue'; // 已经完成
import Vline from './vline/index.vue'; // 已经完成


const components = [
    Actionsheet,
    Button,
    ButtonGroup,
    Cell,
    CellItem,
    Checkbox,
    CheckboxGroup,
    Col,
    Collapse,
    CollapseItem,
    Confirm,
    CountUp,
    Dialog,
    FullLoad,
    Icon,
    Input,
    KeyInput,
    Loading,
    Marquee,
    Notice,
    Number,
    Popup,
    Radio,
    RadioGroup,
    Row,
    Scroll,
    Share,
    Slide,
    SlideItem,
    Step,
    StepItem,
    Tabs,
    TabsItem,
    Toast,
    Vlink, 
    Vline,   
]

const install = Vue => {
    components.forEach(key => {
        Vue.use(key)
    })
}

if (typeof window !== 'undefined' && window.Vue) {
    install(window.Vue)
}

const version = '0.1.3'

export {
    install,
    version,
    Actionsheet,
    Button,
    ButtonGroup,
    Cell,
    CellItem,
    Checkbox,
    CheckboxGroup,
    Col,
    Collapse,
    CollapseItem,
    Confirm,
    CountUp,
    Dialog,
    FullLoad,
    Icon,
    Input,
    KeyInput,
    Loading,
    Marquee,
    Notice,
    Number,
    Popup,
    Radio,
    RadioGroup,
    Row,
    Scroll,
    Share,
    Slide,
    SlideItem,
    Step,
    StepItem,
    Tabs,
    TabsItem,
    Toast,
    Vlink, 
    Vline,   
}

export default {
    install,
    version
};

==> jdvue-0.1.6.tgz: package/src/components/index.js <==
import '../assets/common.less';

import Actionsheet from './actionsheet/index.vue';
import Button from './button/index.vue';
import Cell from './cell/index.vue';
import CellItem from './cell-item/index.vue';
import Checkbox from './checkbox/index.vue';
import CheckboxGroup from './checkbox-group/index.vue';
import Col from './col/index.vue';
import Collapse from './collapse/index.vue';
import CollapseItem from './collapse-item/index.vue';
import Confirm from './confirm/index.vue';
import CountUp from './count-up/index.vue';
import Dialog from './dialog/index.vue';
import FullLoad from './full-load/index.vue';
import Icon from './icon/index.vue';
import Input from './input/index.vue';
import KeyInput from './key-input/index.vue';
import Loading from './loading/index.vue';
import Marquee from './marquee/index.vue';
import Notice from './notice/index.vue';
import Number from './number/index.vue';
import Popup from './popup/index.vue';
import Radio from './radio/index.vue';
import RadioGroup from './radio-group/index.vue';
import Row from './row/index.vue';
import Scroll from './scroll/index.vue';
import Share from './share/index.vue';
import Slide from './slide/index.vue';
import SlideItem from './slide-item/index.vue';
import Step from './step/index.vue';
import StepItem from './step-item/index.vue';
import Tabs from './tabs/index.vue';
import TabsItem from './tabs-item/index.vue';
import Toast from './toast/index.vue';
import Vlink from './vlink/index.vue';
import Vline from './vline/index.vue';

const components = {
    Actionsheet,
    Button,
    Cell,
    CellItem,
    Checkbox,
    CheckboxGroup,
    Col,
    Collapse,
    CollapseItem,
    Confirm,
    CountUp,
    Dialog,
    FullLoad,
    Icon,
    Input,
    KeyInput,
    Loading,
    Marquee,
    Notice,
    Number,
    Popup,
    Radio,
    RadioGroup,
    Row,
    Scroll,
    Share,
    Slide,
    SlideItem,
    Step,
    StepItem,
    Tabs,
    TabsItem,
    Toast,
    Vlink, 
    Vline,   
}

const install = Vue => {
    if (install.installed) return;
    
    Object.keys(components).forEach(key => {
        Vue.component(key, components[key]);
    });
}

if (typeof window !== 'undefined' && window.Vue) {
    install(window.Vue)
}

const version = '0.1.6'

export {
    install,
    version,
    Actionsheet,
    Button,
    Cell,
    CellItem,
    Checkbox,
    CheckboxGroup,
    Col,
    Collapse,
    CollapseItem,
    Confirm,
    CountUp,
    Dialog,
    FullLoad,
    Icon,
    Input,
    KeyInput,
    Loading,
    Marquee,
    Notice,
    Number,
    Popup,
    Radio,
    RadioGroup,
    Row,
    Scroll,
    Share,
    Slide,
    SlideItem,
    Step,
    StepItem,
    Tabs,
    TabsItem,
    Toast,
    Vlink, 
    Vline,   
}

export default {
    install,
    version
};
